@@ -107,6 +107,29 @@ setXCursor ()
    XDefineCursor (xDisplay, xWindow, cursor);
 }
 
+static void
+setUtf8prop (const char* prop_name, const std::string & value)
+{
+   Atom utf8 = XInternAtom (xDisplay, "UTF8_STRING", false);
+   Atom prop = XInternAtom (xDisplay, prop_name, false);
+   XChangeProperty (xDisplay, xWindow, prop, utf8, 8, PropModeReplace,
+                    (const unsigned char*) value.data (), value.size ());
+}
+
+static void
+setXWindowName (const std::string & name)
+{
+   XStoreName (xDisplay, xWindow, name.c_str ());
+   setUtf8prop ("_NET_WM_NAME", name);
+}
+
+static void
+setXWindowIconName (const std::string & name)
+{
+   XSetIconName (xDisplay, xWindow, name.c_str ());
+   setUtf8prop ("_NET_WM_ICON_NAME", name);
+}
+
 static void
 makeXWindow (const char* name, int width, int height, int px, int py,
              EGLDisplay eglDpy, EGLContext& eglCtx, EGLSurface& eglSurface)
@@ -198,6 +221,12 @@ makeXWindow (const char* name, int width, int height, int px, int py,
                           nullptr, 0, &sizeHints, &wmHints, &classHint);
    }
 
+   {
+      std::string title {name};
+      setXWindowName (title);
+      setXWindowIconName (title);
+   }
+
    {
       // set NET_WM_PID to the process ID to link the window to the pid
       Atom _NET_WM_PID = XInternAtom (xDisplay, "_NET_WM_PID", false);
@@ -410,6 +439,9 @@ startShell (const char* execPath, const char* const argv[])
       if (setenv ("TERM", "xterm-256color", 1) < 0)
          SYS_ERROR ("setenv TERM");
 
+      if (setenv ("COLORTERM", "truecolor", 1) < 0)
+         SYS_ERROR ("setenv COLORTERM");
+
       if (execvp (execPath, (char * const *) argv) < 0)
          SYS_ERROR ("execvp of ", execPath);
    }
@@ -493,7 +525,7 @@ onKeyPress (XEvent& event, XIC& xic, int ptyFd)
       selMgr->getSelection (selMgr->getClipboard (), xkevt.time, pasteCb);
       return false;
    }
-   if ((ks == XK_Insert || ks == XK_KP_Insert) && mod == VtModifier::shift)
+   if (ks == XK_Insert && mod == VtModifier::shift)
    {
       selMgr->getSelection (selMgr->getPrimary (), xkevt.time, pasteCb);
       return false;
@@ -1086,14 +1118,14 @@ handleOsc (int cmd, const std::string& arg)
    switch (cmd)
    {
    case 0: // Change Icon Name & Window Title
-      XStoreName (xDisplay, xWindow, arg.c_str ());
-      XSetIconName (xDisplay, xWindow, arg.c_str ());
+      setXWindowName (arg);
+      setXWindowIconName (arg);
       break;
    case 1: // Change Icon Name
-      XSetIconName (xDisplay, xWindow, arg.c_str ());
+      setXWindowIconName (arg);
       break;
    case 2: // Change Window Title
-      XStoreName (xDisplay, xWindow, arg.c_str ());
+      setXWindowName (arg);
       break;
    case 52: // Manipulate Selection Data
    {
